This is the mail archive of the binutils@sourceware.org mailing list for the binutils project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

[2/3] Spelling fixes


On Thu, May 26, 2011 at 09:35:16AM +0200, Stephen Kitt wrote:
> The Lintian package validation tool in Debian picked up a few spelling
> mistakes in binutils (mainly "preceeding" instead of "preceding" and
> "endianess" instead of "endianness"). The following patch fixes these
> mistakes in the messages which end up potentially being seen by the
> user; I'll follow up with patches for the comments and finally the
> code. As suggested by Jonathan Nieder (see
> http://bugs.debian.org/604696 for the corresponding Debian bug report)
> I've left the changelogs as is.

Here's the patch for the comments.

Regards,

Stephen


diff -urN upstream.messages/bfd/coff-mcore.c upstream.comments/bfd/coff-mcore.c
--- upstream.messages/bfd/coff-mcore.c	2011-04-19 10:03:32.000000000 +0200
+++ upstream.comments/bfd/coff-mcore.c	2011-05-26 07:23:26.211254894 +0200
@@ -377,7 +377,7 @@
   if (info->relocatable)
     return TRUE;
 
-  /* Check if we have the same endianess */
+  /* Check if we have the same endianness */
   if (   input_bfd->xvec->byteorder != output_bfd->xvec->byteorder
       && output_bfd->xvec->byteorder != BFD_ENDIAN_UNKNOWN)
     {
diff -urN upstream.messages/bfd/coff-stgo32.c upstream.comments/bfd/coff-stgo32.c
--- upstream.messages/bfd/coff-stgo32.c	2011-04-19 10:03:32.000000000 +0200
+++ upstream.comments/bfd/coff-stgo32.c	2011-05-26 07:23:26.211254894 +0200
@@ -102,7 +102,7 @@
 
 #include "coff-i386.c"
 
-/* This macro is used, because I cannot assume the endianess of the
+/* This macro is used, because I cannot assume the endianness of the
    host system.  */
 #define _H(index) (H_GET_16 (abfd, (header+index*2)))
 
diff -urN upstream.messages/bfd/elf32-arm.c upstream.comments/bfd/elf32-arm.c
--- upstream.messages/bfd/elf32-arm.c	2011-05-19 10:39:28.000000000 +0200
+++ upstream.comments/bfd/elf32-arm.c	2011-05-26 07:23:26.231254610 +0200
@@ -10220,7 +10220,7 @@
 		    - relocation;
 		  addend += msec->output_section->vma + msec->output_offset;
 
-		  /* Cases here must match those in the preceeding
+		  /* Cases here must match those in the preceding
 		     switch statement.  */
 		  switch (r_type)
 		    {
@@ -15431,7 +15431,7 @@
   bfd_boolean flags_compatible = TRUE;
   asection *sec;
 
-  /* Check if we have the same endianess.  */
+  /* Check if we have the same endianness.  */
   if (! _bfd_generic_verify_endian_match (ibfd, obfd))
     return FALSE;
 
diff -urN upstream.messages/bfd/elf32-m68hc1x.c upstream.comments/bfd/elf32-m68hc1x.c
--- upstream.messages/bfd/elf32-m68hc1x.c	2011-04-19 10:03:32.000000000 +0200
+++ upstream.comments/bfd/elf32-m68hc1x.c	2011-05-26 07:23:26.235254554 +0200
@@ -1188,7 +1188,7 @@
   flagword new_flags;
   bfd_boolean ok = TRUE;
 
-  /* Check if we have the same endianess */
+  /* Check if we have the same endianness */
   if (!_bfd_generic_verify_endian_match (ibfd, obfd))
     return FALSE;
 
diff -urN upstream.messages/bfd/elf32-mcore.c upstream.comments/bfd/elf32-mcore.c
--- upstream.messages/bfd/elf32-mcore.c	2011-04-19 10:03:32.000000000 +0200
+++ upstream.comments/bfd/elf32-mcore.c	2011-05-26 07:23:26.239254498 +0200
@@ -55,7 +55,7 @@
   flagword old_flags;
   flagword new_flags;
 
-  /* Check if we have the same endianess.  */
+  /* Check if we have the same endianness.  */
   if (! _bfd_generic_verify_endian_match (ibfd, obfd))
     return FALSE;
 
diff -urN upstream.messages/bfd/elf32-mep.c upstream.comments/bfd/elf32-mep.c
--- upstream.messages/bfd/elf32-mep.c	2011-04-19 10:03:32.000000000 +0200
+++ upstream.comments/bfd/elf32-mep.c	2011-05-26 07:23:26.243254442 +0200
@@ -606,7 +606,7 @@
   flagword old_flags, new_flags;
   flagword old_partial, new_partial;
 
-  /* Check if we have the same endianess.  */
+  /* Check if we have the same endianness.  */
   if (_bfd_generic_verify_endian_match (ibfd, obfd) == FALSE)
     return FALSE;
 
diff -urN upstream.messages/bfd/elf32-mt.c upstream.comments/bfd/elf32-mt.c
--- upstream.messages/bfd/elf32-mt.c	2011-04-19 10:03:32.000000000 +0200
+++ upstream.comments/bfd/elf32-mt.c	2011-05-26 07:23:26.243254442 +0200
@@ -521,7 +521,7 @@
   flagword     old_flags, new_flags;
   bfd_boolean  ok = TRUE;
 
-  /* Check if we have the same endianess.  */
+  /* Check if we have the same endianness.  */
   if (_bfd_generic_verify_endian_match (ibfd, obfd) == FALSE)
     return FALSE;
 
diff -urN upstream.messages/bfd/elf32-ppc.c upstream.comments/bfd/elf32-ppc.c
--- upstream.messages/bfd/elf32-ppc.c	2011-05-23 14:49:10.000000000 +0200
+++ upstream.comments/bfd/elf32-ppc.c	2011-05-26 07:23:26.251254330 +0200
@@ -4145,7 +4145,7 @@
   if (!is_ppc_elf (ibfd) || !is_ppc_elf (obfd))
     return TRUE;
 
-  /* Check if we have the same endianess.  */
+  /* Check if we have the same endianness.  */
   if (! _bfd_generic_verify_endian_match (ibfd, obfd))
     return FALSE;
 
diff -urN upstream.messages/bfd/elf32-xtensa.c upstream.comments/bfd/elf32-xtensa.c
--- upstream.messages/bfd/elf32-xtensa.c	2011-04-19 10:03:32.000000000 +0200
+++ upstream.comments/bfd/elf32-xtensa.c	2011-05-26 07:23:26.267254106 +0200
@@ -3466,7 +3466,7 @@
   unsigned out_mach, in_mach;
   flagword out_flag, in_flag;
 
-  /* Check if we have the same endianess.  */
+  /* Check if we have the same endianness.  */
   if (!_bfd_generic_verify_endian_match (ibfd, obfd))
     return FALSE;
 
diff -urN upstream.messages/bfd/elf64-ppc.c upstream.comments/bfd/elf64-ppc.c
--- upstream.messages/bfd/elf64-ppc.c	2011-05-23 14:49:10.000000000 +0200
+++ upstream.comments/bfd/elf64-ppc.c	2011-05-26 07:23:26.279253935 +0200
@@ -2733,7 +2733,7 @@
 static bfd_boolean
 ppc64_elf_merge_private_bfd_data (bfd *ibfd, bfd *obfd)
 {
-  /* Check if we have the same endianess.  */
+  /* Check if we have the same endianness.  */
   if (ibfd->xvec->byteorder != obfd->xvec->byteorder
       && ibfd->xvec->byteorder != BFD_ENDIAN_UNKNOWN
       && obfd->xvec->byteorder != BFD_ENDIAN_UNKNOWN)
diff -urN upstream.messages/bfd/elfxx-mips.c upstream.comments/bfd/elfxx-mips.c
--- upstream.messages/bfd/elfxx-mips.c	2011-05-24 00:43:05.000000000 +0200
+++ upstream.comments/bfd/elfxx-mips.c	2011-05-26 07:23:26.287253822 +0200
@@ -12538,7 +12538,7 @@
   bfd_boolean null_input_bfd = TRUE;
   asection *sec;
 
-  /* Check if we have the same endianess */
+  /* Check if we have the same endianness */
   if (! _bfd_generic_verify_endian_match (ibfd, obfd))
     {
       (*_bfd_error_handler)
diff -urN upstream.messages/bfd/netbsd.h upstream.comments/bfd/netbsd.h
--- upstream.messages/bfd/netbsd.h	2011-04-19 10:03:32.000000000 +0200
+++ upstream.comments/bfd/netbsd.h	2011-05-26 07:23:26.287253822 +0200
@@ -108,7 +108,7 @@
   /* The NetBSD magic number is always big-endian */
 #ifndef TARGET_IS_BIG_ENDIAN_P
   /* XXX aren't there any macro to change byteorder of a word independent of
-     the host's or target's endianesses?  */
+     the host's or target's endiannesses?  */
   execp->a_info
     = (execp->a_info & 0xff) << 24 | (execp->a_info & 0xff00) << 8
       | (execp->a_info & 0xff0000) >> 8 | (execp->a_info & 0xff000000) >> 24;
diff -urN upstream.messages/bfd/nlmcode.h upstream.comments/bfd/nlmcode.h
--- upstream.messages/bfd/nlmcode.h	2011-04-19 10:03:32.000000000 +0200
+++ upstream.comments/bfd/nlmcode.h	2011-05-26 07:23:26.287253822 +0200
@@ -491,7 +491,7 @@
 		  NLM_SIGNATURE_SIZE) != 0)
     goto got_wrong_format_error;
 
-  /* There's no supported way to discover the endianess of an NLM, so test for
+  /* There's no supported way to discover the endianness of an NLM, so test for
      a sane version number after doing byte swapping appropriate for this
      XVEC.  (Hack alert!)  */
   if (i_fxdhdrp->version > 0xFFFF)
diff -urN upstream.messages/bfd/vms-alpha.c upstream.comments/bfd/vms-alpha.c
--- upstream.messages/bfd/vms-alpha.c	2011-05-07 16:39:59.000000000 +0200
+++ upstream.comments/bfd/vms-alpha.c	2011-05-26 07:23:26.295253710 +0200
@@ -440,7 +440,7 @@
 {
   struct bfd_link_hash_table root;
 
-  /* Vector of shared libaries.  */
+  /* Vector of shared libraries.  */
   struct vector_type shrlibs;
 
   /* Fixup section.  */
diff -urN upstream.messages/gas/as.c upstream.comments/gas/as.c
--- upstream.messages/gas/as.c	2011-04-19 10:03:33.000000000 +0200
+++ upstream.comments/gas/as.c	2011-05-26 07:23:26.295253710 +0200
@@ -461,7 +461,7 @@
   static const struct option std_longopts[] =
   {
     /* Note: commas are placed at the start of the line rather than
-       the end of the preceeding line so that it is simpler to
+       the end of the preceding line so that it is simpler to
        selectively add and remove lines from this list.  */
     {"alternate", no_argument, NULL, OPTION_ALTERNATE}
     /* The entry for "a" is here to prevent getopt_long_only() from
diff -urN upstream.messages/gas/config/tc-ppc.c upstream.comments/gas/config/tc-ppc.c
--- upstream.messages/gas/config/tc-ppc.c	2011-05-19 10:39:28.000000000 +0200
+++ upstream.comments/gas/config/tc-ppc.c	2011-05-26 07:23:26.299253654 +0200
@@ -1153,7 +1153,7 @@
       else if (strcmp (arg, "emb") == 0)
 	ppc_flags |= EF_PPC_EMB;
 
-      /* -mlittle/-mbig set the endianess.  */
+      /* -mlittle/-mbig set the endianness.  */
       else if (strcmp (arg, "little") == 0
 	       || strcmp (arg, "little-endian") == 0)
 	{
diff -urN upstream.messages/gold/dynobj.h upstream.comments/gold/dynobj.h
--- upstream.messages/gold/dynobj.h	2011-04-19 10:03:33.000000000 +0200
+++ upstream.comments/gold/dynobj.h	2011-05-26 07:23:26.299253654 +0200
@@ -647,7 +647,7 @@
   // Contents of --version-script, if passed, or NULL.
   const Version_script_info& version_script_;
   // Whether we need to insert a base version.  This is only used for
-  // shared libaries and is cleared when the base version is defined.
+  // shared libraries and is cleared when the base version is defined.
   bool needs_base_version_;
 };
 
diff -urN upstream.messages/gold/output.cc upstream.comments/gold/output.cc
--- upstream.messages/gold/output.cc	2011-04-27 14:09:50.000000000 +0200
+++ upstream.comments/gold/output.cc	2011-05-26 07:23:26.303253598 +0200
@@ -481,7 +481,7 @@
     }
 }
 
-// Write out the file header with appropriate size and endianess.
+// Write out the file header with appropriate size and endianness.
 
 template<int size, bool big_endian>
 void
diff -urN upstream.messages/include/coff/i860.h upstream.comments/include/coff/i860.h
--- upstream.messages/include/coff/i860.h	2011-04-19 10:03:33.000000000 +0200
+++ upstream.comments/include/coff/i860.h	2011-05-26 07:23:26.303253598 +0200
@@ -58,7 +58,7 @@
 #define RELSZ 10
 
 /* The relocation directory entry types.
-     PAIR   : The low half that follows relates to the preceeding HIGH[ADJ].
+     PAIR   : The low half that follows relates to the preceding HIGH[ADJ].
      HIGH   : The high half of a 32-bit constant.
      LOWn   : The low half, insn bits 15..(n-1), 2^n-byte aligned. 
      SPLITn : The low half, insn bits 20..16 and 10..(n-1), 2^n-byte aligned. 
diff -urN upstream.messages/include/elf/common.h upstream.comments/include/elf/common.h
--- upstream.messages/include/elf/common.h	2011-04-19 10:03:33.000000000 +0200
+++ upstream.comments/include/elf/common.h	2011-05-26 07:23:26.307253542 +0200
@@ -159,7 +159,7 @@
 #define EM_MMA		 54	/* Fujitsu Multimedia Accelerator */
 #define EM_PCP		 55	/* Siemens PCP */
 #define EM_NCPU		 56	/* Sony nCPU embedded RISC processor */
-#define EM_NDR1		 57	/* Denso NDR1 microprocesspr */
+#define EM_NDR1		 57	/* Denso NDR1 microprocessor */
 #define EM_STARCORE	 58	/* Motorola Star*Core processor */
 #define EM_ME16		 59	/* Toyota ME16 processor */
 #define EM_ST100	 60	/* STMicroelectronics ST100 processor */
diff -urN upstream.messages/include/elf/reloc-macros.h upstream.comments/include/elf/reloc-macros.h
--- upstream.messages/include/elf/reloc-macros.h	2011-04-19 10:03:33.000000000 +0200
+++ upstream.comments/include/elf/reloc-macros.h	2011-05-26 07:23:26.307253542 +0200
@@ -48,7 +48,7 @@
    set to the value of the whichever *_RELOC macro preceeds it plus
    one.  Therefore if you intend to use the symbol as a sentinel for
    the highest valid macro value you should make sure that the
-   preceeding *_RELOC macro is the highest valid number.  ie a
+   preceding *_RELOC macro is the highest valid number.  ie a
    declaration like this:
 
    	START_RELOC_NUMBERS (foo)
diff -urN upstream.messages/ld/scripttempl/epocpe.sc upstream.comments/ld/scripttempl/epocpe.sc
--- upstream.messages/ld/scripttempl/epocpe.sc	2011-04-19 10:03:33.000000000 +0200
+++ upstream.comments/ld/scripttempl/epocpe.sc	2011-05-26 07:23:26.307253542 +0200
@@ -74,7 +74,7 @@
      on fork.  This used to be named ".data$nocopy".  The linker used
      to include this between __data_start__ and __data_end__, but that
      breaks building the cygwin32 dll.  Instead, we name the section
-     ".data_cygwin_nocopy" and explictly include it after __data_end__. */
+     ".data_cygwin_nocopy" and explicitly include it after __data_end__. */
 
   .data ${RELOCATING+BLOCK(__section_alignment__)} : 
   {
diff -urN upstream.messages/ld/scripttempl/i386beos.sc upstream.comments/ld/scripttempl/i386beos.sc
--- upstream.messages/ld/scripttempl/i386beos.sc	2011-04-19 10:03:33.000000000 +0200
+++ upstream.comments/ld/scripttempl/i386beos.sc	2011-05-26 07:23:26.307253542 +0200
@@ -68,7 +68,7 @@
      on fork.  This used to be named ".data$nocopy".  The linker used
      to include this between __data_start__ and __data_end__, but that
      breaks building the cygwin32 dll.  Instead, we name the section
-     ".data_cygwin_nocopy" and explictly include it after __data_end__. */
+     ".data_cygwin_nocopy" and explicitly include it after __data_end__. */
 
   .data ${RELOCATING+BLOCK(__section_alignment__)} : 
   {
diff -urN upstream.messages/ld/scripttempl/mcorepe.sc upstream.comments/ld/scripttempl/mcorepe.sc
--- upstream.messages/ld/scripttempl/mcorepe.sc	2011-04-19 10:03:33.000000000 +0200
+++ upstream.comments/ld/scripttempl/mcorepe.sc	2011-05-26 07:23:26.307253542 +0200
@@ -74,7 +74,7 @@
      on fork.  This used to be named ".data$nocopy".  The linker used
      to include this between __data_start__ and __data_end__, but that
      breaks building the cygwin32 dll.  Instead, we name the section
-     ".data_cygwin_nocopy" and explictly include it after __data_end__. */
+     ".data_cygwin_nocopy" and explicitly include it after __data_end__. */
 
   .data ${RELOCATING+BLOCK(__section_alignment__)} : 
   {
diff -urN upstream.messages/ld/scripttempl/pep.sc upstream.comments/ld/scripttempl/pep.sc
--- upstream.messages/ld/scripttempl/pep.sc	2011-05-08 01:44:05.000000000 +0200
+++ upstream.comments/ld/scripttempl/pep.sc	2011-05-26 07:23:26.311253486 +0200
@@ -91,7 +91,7 @@
      on fork.  This used to be named ".data$nocopy".  The linker used
      to include this between __data_start__ and __data_end__, but that
      breaks building the cygwin32 dll.  Instead, we name the section
-     ".data_cygwin_nocopy" and explictly include it after __data_end__. */
+     ".data_cygwin_nocopy" and explicitly include it after __data_end__. */
 
   .data ${RELOCATING+BLOCK(__section_alignment__)} : 
   {
diff -urN upstream.messages/ld/scripttempl/pe.sc upstream.comments/ld/scripttempl/pe.sc
--- upstream.messages/ld/scripttempl/pe.sc	2011-05-08 01:44:05.000000000 +0200
+++ upstream.comments/ld/scripttempl/pe.sc	2011-05-26 07:23:26.315253430 +0200
@@ -90,7 +90,7 @@
      on fork.  This used to be named ".data$nocopy".  The linker used
      to include this between __data_start__ and __data_end__, but that
      breaks building the cygwin32 dll.  Instead, we name the section
-     ".data_cygwin_nocopy" and explictly include it after __data_end__. */
+     ".data_cygwin_nocopy" and explicitly include it after __data_end__. */
 
   .data ${RELOCATING+BLOCK(__section_alignment__)} : 
   {
diff -urN upstream.messages/opcodes/arm-dis.c upstream.comments/opcodes/arm-dis.c
--- upstream.messages/opcodes/arm-dis.c	2011-05-26 07:22:57.419660261 +0200
+++ upstream.comments/opcodes/arm-dis.c	2011-05-26 07:23:26.319253373 +0200
@@ -4702,7 +4702,7 @@
 	  if (!found)
 	    {
 	      /* No mapping symbol found at this address.  Look backwards
-		 for a preceeding one.  */
+		 for a preceding one.  */
 	      for (n = start - 1; n >= 0; n--)
 		{
 		  if (get_map_sym_type (info, n, &type))
@@ -4762,7 +4762,7 @@
 	  if (!found)
 	    {
 	      /* No mapping symbol found at this address.  Look backwards
-		 for a preceeding one.  */
+		 for a preceding one.  */
 	      for (n = start - 1; n >= 0; n--)
 		{
 		  if (get_sym_code_type (info, n, &type))


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
diff -urN upstream.messages/bfd/elf32-avr.c upstream.comments/bfd/elf32-avr.c
--- upstream.messages/bfd/elf32-avr.c	2011-05-26 07:22:57.187663528 +0200
+++ upstream.comments/bfd/elf32-avr.c	2011-05-26 07:23:58.170806135 +0200
@@ -2008,7 +2008,7 @@
                 if ((0x95 == next_insn_msb) && (0x08 == next_insn_lsb))
                   {
                     /* The next insn is a ret. We possibly could delete
-                       this ret. First we need to check for preceeding
+                       this ret. First we need to check for preceding
                        sbis/sbic/sbrs or cpse "skip" instructions.  */
 
                     int there_is_preceeding_non_skip_insn = 1;
@@ -2023,7 +2023,7 @@
                       printf ("found jmp / ret sequence at address 0x%x\n",
                               (int) dot);
 
                     /* We have to make sure that there is a preceeding insn.  */
                     if (irel->r_offset >= 2)
                       {
                         unsigned char preceeding_msb;
@@ -2023,7 +2023,7 @@
                               (int) dot);
 
-                    /* We have to make sure that there is a preceeding insn.  */
+                    /* We have to make sure that there is a preceding insn.  */
                     if (irel->r_offset >= 2)
                       {
diff -urN upstream.messages/libiberty/pex-win32.c upstream.comments/libiberty/pex-win32.c
--- upstream.messages/libiberty/pex-win32.c	2011-04-21 12:39:41.000000000 +0200
+++ upstream.comments/libiberty/pex-win32.c	2011-05-26 07:23:26.315253430 +0200
@@ -346,14 +346,14 @@
     {
       /* We quote every last argument.  This simplifies the problem;
 	 we need only escape embedded double-quotes and immediately
-	 preceeding backslash characters.  A sequence of backslach characters
+	 preceding backslash characters.  A sequence of backslach characters
 	 that is not follwed by a double quote character will not be
 	 escaped.  */
       for (j = 0; argv[i][j]; j++)
 	{
 	  if (argv[i][j] == '"')
 	    {
 	      /* Escape preceeding backslashes.  */
 	      for (k = j - 1; k >= 0 && argv[i][k] == '\\'; k--)
 		cmdline_len++;
 	      /* Escape the qote character.  */
@@ -346,14 +346,14 @@
 	  if (argv[i][j] == '"')
 	    {
-	      /* Escape preceeding backslashes.  */
+	      /* Escape preceding backslashes.  */
 	      for (k = j - 1; k >= 0 && argv[i][k] == '\\'; k--)
 		cmdline_len++;